@@ -22,14 +22,31 @@ sub call {
             my $write = shift;
 
             if ( @$write == 2 ) {
-                my @body;
+                my ( $closed, @body );
 
                 $ret = [ @$write, \@body ];
 
-                return Plack::Util::inline_object(
-                    write => sub { push @body, $_[0] },
-                    close => sub { },
+                # two copies because we weaken the one that is closed over
+                my $writer;
+                my $ref_up = $writer = Plack::Util::inline_object(
+                    poll_cb => sub {
+                        my $cb = shift;
+
+                        until ( $closed ) {
+                            $cb->($writer);
+                        }
+                    },
+                    write => sub {
+                        push @body, $_[0];
+                    },
+                    close => sub {
+                        $closed = 1;
+                    }
                 );
+
+                weaken($writer);
+
+                return $writer;
             } else {
                 $ret = $write;
                 return;
